Server

Struct Server 

pub struct Server<H, T: Transport = DefaultTransport> { /* private fields */ }
The main server instance.

Generic over handler H and transport backend T.

Implementations

Source

impl<H, T> Server<H, T>
where H: MessageHandler + Send + Sync + 'static, T: Transport, T::Connection: Send + 'static,

pub async fn run(&mut self) -> Result<(), ServerError>

Runs the server, accepting connections and processing messages.

Uses the selected Transport backend to bind and accept connections.

Errors

Returns ServerError if the server fails to start or encounters an error.