pub struct MessageDispatcher { /* private fields */ }Expand description
Dispatcher that routes messages to specific handlers based on template ID.
Implementations
Sourceimpl MessageDispatcher
impl MessageDispatcher
Sourcepub fn register<H: TypedHandler + 'static>(
&mut self,
template_id: u16,
handler: H,
)
pub fn register<H: TypedHandler + 'static>( &mut self, template_id: u16, handler: H, )
Registers a handler for a specific template ID.
Sourcepub fn set_default<H: MessageHandler + 'static>(&mut self, handler: H)
pub fn set_default<H: MessageHandler + 'static>(&mut self, handler: H)
Sets the default handler for unregistered template IDs.
Sourcepub fn has_handler(&self, template_id: u16) -> bool
pub fn has_handler(&self, template_id: u16) -> bool
Returns true if a handler is registered for the given template ID.